{% extends "base.html" %} {% block main %}

## Issues

Thank you for helping the project! This page discusses how you can report potential bugs and suggest new features.

### Reporting a problem

Bugs are problems in existing functionality and they can be reported by opening an issue. If possible, include what you can from the following:

- Brief summary of the problem ideally with a description of what happened and how that differed from what you expected to happen.
- Your operating system version and, if using Sketch2DWeb, your browser version.
- Code snippets to reproduce the bug.

Please add the "Bug" label. If you are unable to open an issue or the problem is security related, please email us at hello@sketchingpy.org.

### Offering a proposal or enhancement

"Enhancement" issues cover requests for making changes to existing functionality. Meanwhile, suggestions for new features are called "proposals" in our projects. For either, please open an issue in our tracker with the following information:

- Short single sentence description of the functionality.
- Rationale and/or detailed description of the new feature.
- Recommendations for design (in terms of API or implementation) if available.
- Questions for the community if applicable.
- Example code if applicable.

If possible, add the "enhancement" or "proposal" label to your issue. A member of the planning group will review your request!

### Note about issues

Issues are part of the open source process. Therefore, they are part of our Code of Conduct and Contribution Guidelines.

### Related materials

- Documentation Issues
- Code of Conduct
- Contribution Guidelines and Agreement
- Governance
- README

{% endblock %}